@@ -4,8 +4,9 @@ use Exporter 'import';
 use Promises6::Util ':all';
 use Promises6::Evo::Builder;
 use Evo::Manager;
+use Evo;
 
-our $VERSION = '0.006';    # VERSION
+our $VERSION = '0.007';    # VERSION
 my @DSL = qw(when_ok when_rejected when_progress promise then);
 our @EXPORT_OK = (@DSL, qw(deferred resolved rejected all race));
 our %EXPORT_TAGS = (all => \@EXPORT_OK, dsl => \@DSL);
@@ -13,7 +14,7 @@ sub deferred { Promises6::Evo::Builder->singleton->deferred() }
 
 # dsl
 sub then {
-  _evo()->current->{'promise'} = _evo()->current('promise')->then(@_);
+  Evo::dsl_stash->{'promise'} = Evo::dsl_stash('promise')->then(@_);
 }
 sub when_ok : prototype(&)       { then(shift, undef, undef) }
 sub when_rejected : prototype(&) { then(undef, shift, undef) }
@@ -71,12 +72,12 @@ sub promise : prototype(&) {
   my $notify  = sub { $d->notify($_[0]) };
 
   my $promise = $d->promise;
-  _evo()->dsl_call(
+  Evo::dsl_call(
     {promise => $d->promise},
     $resolve, $reject, $notify,
     sub {
       $cb->($resolve, $reject, $notify);
-      $promise = _evo()->current('promise');
+      $promise = Evo::dsl_stash('promise');
     }
   );
 
@@ -94,8 +95,6 @@ sub rejected : prototype($) {
   deferred->reject($reason)->promise;
 }
 
-sub _evo { Evo::Manager->singleton }
-
 1;
 
 # ABSTRACT: Promises6 - Promises/A+ with DSL, ES6 syntax and progress notifications
@@ -112,7 +111,7 @@ Promises6 - Promises6 - Promises/A+ with DSL, ES6 syntax and progress notificati
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -297,7 +296,7 @@ compatible. Promises.pm isn't.
 =head2 next_tick and EventLoops perfomance
 
 Don't try to write EventLoop backend. I've written EV example for you
-only to show, that right now current implementation do the right thing
+only to show, that right now dsl_stash implementation do the right thing
 without event_loop. And even the fastest one works 10-20 times slower
 than pure perl with even syntax sugar. That's because timer 0,0 isn't
 the same thing as a next_tick.
